RepositoryError

Enum RepositoryError 

#[non_exhaustive]
pub enum RepositoryError { Sqlx(Error), Migration(MigrateError), Json(Error), Keepsake(KeepsakeError), BackendMismatch { expected: &'static str, actual: String, }, RelationDisabled { relation_id: Uuid, }, RelationSpecIdMismatch { kind: String, name: String, expected_relation_id: Uuid, stored_relation_id: Uuid, }, RelationDefinitionMissing { relation_id: Uuid, }, InvalidLimit { limit: i64, max: i64, }, InvalidLifecycleState { state: String, }, InvalidAuditEventType { event_type: String, }, }
SQL repository errors.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Sqlx(Error)

SQLx returned an error.



Migration(MigrateError)

Migration failed.



Json(Error)

JSON policy could not be encoded or decoded.



Keepsake(KeepsakeError)

A Keepsake core model could not be built.



BackendMismatch

Existing schema metadata belongs to a different backend.

Fields

expected: &'static str

Backend expected by this repository.

actual: String

Backend found in schema metadata.



RelationDisabled

A command tried to mutate a disabled relation.

Fields

relation_id: Uuid

Disabled relation id.



RelationSpecIdMismatch

A typed relation spec conflicts with an existing natural-key row.

Fields

kind: String

Relation kind.

name: String

Relation name.

expected_relation_id: Uuid

Relation id declared by the typed spec.

stored_relation_id: Uuid

Existing stored relation id for the same natural key.



RelationDefinitionMissing

A keepsake row referenced a missing relation definition.

Fields

relation_id: Uuid

Missing relation id.



InvalidLimit

A batch or scan limit was outside the accepted range.

Fields

limit: i64

Provided limit.

max: i64

Maximum accepted limit.



InvalidLifecycleState

A row contained an unknown lifecycle state.

Fields

state: String

Stored state value.



InvalidAuditEventType

A stored audit event carried an unknown event type label.

Fields

event_type: String

Stored event type label.