pub struct AuditCursor {
pub occurred_at: DateTime<Utc>,
pub id: i64,
}Expand description
Keyset cursor for audit event reads in stable (occurred_at, id) order.
Fields
occurred_at: DateTime<Utc>Last seen occurrence time.
id: i64Last seen audit row id.
Implementations
Sourceimpl AuditCursor
impl AuditCursor
Sourcepub const fn after(record: &AuditEventRecord) -> Self
pub const fn after(record: &AuditEventRecord) -> Self
Creates a cursor positioned after a returned audit event.