pub struct AuditOutboxCursor {
pub id: i64,
}Expand description
Keyset cursor for audit outbox export in stable id order.
Fields
id: i64Last seen outbox row id.
Implementations
Sourceimpl AuditOutboxCursor
impl AuditOutboxCursor
Sourcepub const fn after(record: &AuditOutboxRecord) -> Self
pub const fn after(record: &AuditOutboxRecord) -> Self
Creates a cursor positioned after a returned outbox record.