pub struct TimedKeepsakeRepository<'repo, C = NoopRelationCache> { /* private fields */ }Expand description
Timestamp-scoped repository view.
This wrapper does not read the system clock. Callers choose the timestamp once at an operation boundary, then use the forwarding methods to keep related writes and expiry scans on the same deterministic instant.
Implementations
Sourceimpl<'repo, C> TimedKeepsakeRepository<'repo, C>where
C: RelationCache,
impl<'repo, C> TimedKeepsakeRepository<'repo, C>where
C: RelationCache,
Sourcepub const fn repository(&self) -> &'repo KeepsakeRepository<C>
pub const fn repository(&self) -> &'repo KeepsakeRepository<C>
Returns the repository backing this timestamp-scoped view.
Sourcepub const fn timestamp(&self) -> DateTime<Utc>
pub const fn timestamp(&self) -> DateTime<Utc>
Returns the timestamp applied by forwarding methods.
Sourcepub async fn upsert_relation(
&self,
relation: &RelationDefinition,
) -> RepositoryResult<RelationDefinition>
pub async fn upsert_relation( &self, relation: &RelationDefinition, ) -> RepositoryResult<RelationDefinition>
Inserts or updates a relation definition using this view’s timestamp.
Sourcepub async fn upsert_relation_spec<Spec>(
&self,
) -> RepositoryResult<RelationDefinition>where
Spec: RelationSpec,
pub async fn upsert_relation_spec<Spec>(
&self,
) -> RepositoryResult<RelationDefinition>where
Spec: RelationSpec,
Inserts or updates a typed relation spec using this view’s timestamp.
Sourcepub async fn set_relation_enabled(
&self,
relation_id: RelationId,
enabled: bool,
) -> RepositoryResult<bool>
pub async fn set_relation_enabled( &self, relation_id: RelationId, enabled: bool, ) -> RepositoryResult<bool>
Enables or disables a relation using this view’s timestamp.
Sourcepub async fn apply(
&self,
subject: &SubjectRef,
relation_id: RelationId,
metadata: &BTreeMap<String, String>,
) -> RepositoryResult<AppliedKeepsake>
pub async fn apply( &self, subject: &SubjectRef, relation_id: RelationId, metadata: &BTreeMap<String, String>, ) -> RepositoryResult<AppliedKeepsake>
Applies a keepsake relation idempotently using this view’s timestamp.
Sourcepub async fn apply_spec<Spec>(
&self,
subject: &SubjectRef,
metadata: &BTreeMap<String, String>,
) -> RepositoryResult<AppliedKeepsake>where
Spec: RelationSpec,
pub async fn apply_spec<Spec>(
&self,
subject: &SubjectRef,
metadata: &BTreeMap<String, String>,
) -> RepositoryResult<AppliedKeepsake>where
Spec: RelationSpec,
Applies a typed keepsake relation idempotently using this view’s timestamp.
Sourcepub async fn apply_without_metadata(
&self,
subject: &SubjectRef,
relation_id: RelationId,
) -> RepositoryResult<AppliedKeepsake>
pub async fn apply_without_metadata( &self, subject: &SubjectRef, relation_id: RelationId, ) -> RepositoryResult<AppliedKeepsake>
Applies a keepsake relation with empty metadata using this view’s timestamp.
Sourcepub async fn apply_spec_without_metadata<Spec>(
&self,
subject: &SubjectRef,
) -> RepositoryResult<AppliedKeepsake>where
Spec: RelationSpec,
pub async fn apply_spec_without_metadata<Spec>(
&self,
subject: &SubjectRef,
) -> RepositoryResult<AppliedKeepsake>where
Spec: RelationSpec,
Applies a typed keepsake relation with empty metadata using this view’s timestamp.
Sourcepub async fn revoke(&self, keepsake_id: Uuid) -> RepositoryResult<bool>
pub async fn revoke(&self, keepsake_id: Uuid) -> RepositoryResult<bool>
Revokes an active keepsake using this view’s timestamp.
Sourcepub async fn due_timed_expiry(
&self,
limit: i64,
) -> RepositoryResult<Vec<TimedExpiryCandidate>>
pub async fn due_timed_expiry( &self, limit: i64, ) -> RepositoryResult<Vec<TimedExpiryCandidate>>
Lists due timed expiry candidates using this view’s timestamp.
Sourcepub async fn expire_due_timed(&self, limit: i64) -> RepositoryResult<u64>
pub async fn expire_due_timed(&self, limit: i64) -> RepositoryResult<u64>
Expires a stable batch of due timed keepsakes using this view’s timestamp.
Sourcepub async fn upsert_counter_projection(
&self,
keepsake_id: Uuid,
key: &str,
value: i64,
) -> RepositoryResult<()>
pub async fn upsert_counter_projection( &self, keepsake_id: Uuid, key: &str, value: i64, ) -> RepositoryResult<()>
Upserts a simple fulfillment counter projection using this view’s timestamp.