Crate keepsake_sqlx

Crate keepsake_sqlx 

SQLx adapter for Keepsake.

Modules

prelude
Common imports for application modules using the SQLx adapter.

Structs

ActiveRelation
Active keepsake membership with its stored relation definition.
AppliedKeepsake
Result of an apply operation.
AuditCursor
Keyset cursor for audit event reads in stable (occurred_at, id) order.
AuditEventRecord
A persisted audit event together with its stable storage id.
FulfilledExpiryCandidate
Due fulfillment expiry candidate.
LocalRelationCache
Local in-process relation definition cache.
LocalRelationCacheConfig
Configuration for local in-process relation definition caching.
MembershipCursor
Keyset cursor for active relation membership scans.
NoopRelationCache
Relation cache implementation that never stores entries.
PostgresBackend
Postgres backend marker.
SqlxKeepsakeRepository
SQLx-backed keepsake repository.
TimedExpiryCandidate
Due timed expiry candidate.
TimedSqlxKeepsakeRepository
Timestamp-scoped repository view.

Enums

RepositoryError
SQL repository errors.

Traits

KeepsakeSqlxBackend
SQLx backend supported by Keepsake.
RelationCache
Adapter for relation definition caching.

Type Aliases

KeepsakeRepository
Default Postgres-backed keepsake repository.
PostgresKeepsakeRepository
Postgres-backed keepsake repository.
RepositoryResult
Result alias for SQL repository operations.
TimedKeepsakeRepository
Default Postgres timestamp-scoped repository view.